@@ -185,7 +185,7 @@ def wait_for_strings(cb, seconds, *strings):
     """
     buff = '<UNINITIALIZED>'
 
-    for _ in range(int(seconds * 20)):
+    for _ in range(1+int(seconds * 20)):
         time.sleep(0.05)
         buff = cb()
         check_strings = list(strings)
